/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.File;

import org.junit.BeforeClass;
import org.junit.Test;
import org.ow2.petals.microkernel.configuration.ConfigurationTestUtils;
import org.ow2.petals.topology.TopologyBuilder;
import org.ow2.petals.topology.TopologyException;
import org.ow2.petals.topology.generated.Topology;

/**
 * Unit test about the default configuration
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class DefaultConfigurationIT {

    private final static String PROPERTY_NAME_ARCHIVE_BASE_DIRECTORY = "archive-base-directory";

    private static File CONF_DIRECTORY = null;

    @BeforeClass
    public static void setup() {
        final String archiveBaseDirectoryStr = System.getProperty(PROPERTY_NAME_ARCHIVE_BASE_DIRECTORY);
        assertNotNull("System property '" + PROPERTY_NAME_ARCHIVE_BASE_DIRECTORY + "' not set.",
                archiveBaseDirectoryStr);
        CONF_DIRECTORY = new File(archiveBaseDirectoryStr, "conf");
        assertTrue("The configuration directory '" + CONF_DIRECTORY.getAbsolutePath() + "' does not exist",
                CONF_DIRECTORY.exists());
        assertTrue("The configuration directory '" + CONF_DIRECTORY.getAbsolutePath() + "' is not a directory",
                CONF_DIRECTORY.isDirectory());
    }

    /**
     * <p>
     * Verify that the default topology file is valid.
     * </p>
     * <p>
     * The topology file is get through the system property {@value #PROPERTY_NAME_CONF_DIRECTORY}
     * </p>
     * <p>
     * Expected results: no error occurs parsing the default topology file, and it contains a basic sample topology
     * </p>
     */
    @Test
    public void testDefaultTopology() throws TopologyException {

        final File topologyFile = new File(CONF_DIRECTORY, "topology.xml");
        final Topology defaultTopology = TopologyBuilder.createTopology(topologyFile);
        assertNotNull("Default topology null", defaultTopology);

        ConfigurationTestUtils.assertBasicSampleTopology(defaultTopology);
    }

}
